package info.freelibrary.maven;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.model.Profile;
import org.apache.maven.project.MavenProject;
import org.apache.maven.plugin.logging.Log;

import info.freelibrary.util.FileUtils;
import info.freelibrary.util.StringUtils;

import java.io.File;
import java.io.IOException;

import java.util.List;
import java.util.Properties;

/**
 * Goal which copies native files from <code>LD_LIBRARY_PATH</code> to
 * <code>java.library.path</code>.
 * 
 * @goal copy
 */
public class LLP2JLPMojo extends AbstractMojo {

	/**
	 * The Maven project.
	 * 
	 * @parameter expression="${project}"
	 * @readonly
	 */
	private MavenProject myProject;

	public void execute() throws MojoExecutionException {
		String jlp = System.getProperty("java.library.path");
		Log log = getLog();

		List<?> profiles = myProject.getActiveProfiles();

		for (int index = 0; index < profiles.size(); index++) {
			Profile profile = (Profile) profiles.get(index);
			Properties properties = profile.getProperties();
			String llp = properties.getProperty("LD_LIBRARY_PATH");

			if (llp == null) {
				llp = properties.getProperty("DYLD_LIBRARY_PATH");
			}

			if (jlp != null && !jlp.contains(":")) {
				if (llp != null) {
					File jlpDir = new File(jlp);
					File llpDir = new File(llp);

					if (log.isInfoEnabled()) {
						log.info(
								StringUtils.formatMessage(
										"Copying files from {} to {}",
										new String[] {
												llpDir.getAbsolutePath(),
												jlpDir.getAbsolutePath() }));

					}

					try {
						FileUtils.copy(llpDir, jlpDir);
					}
					catch (IOException details) {
						if (log.isErrorEnabled()) {
							log.error(details.getMessage(), details);
						}
					}
				}
				else if (log.isErrorEnabled()) {
					log.error("LD_LIBRARY_PATH not set in Maven");
				}
			}
			else if (log.isErrorEnabled()) {
				log.error("java.library.path should be set in MAVEN_OPTS");
			}
		}
	}
}
